@@ -1,6 +1,4 @@
 package Mojolicious::Plugin::AttributeMaker::Extension;
-use strict;
-use warnings;
 #Base class :)
 #Infected by Mojolicious::Plugin::Router;
 =head1 NAME
